@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# © Copyright EnterpriseDB UK Limited 2018-2023
+# © Copyright EnterpriseDB UK Limited 2018-2025
 #
 # This file is part of Barman.
 #
@@ -559,7 +559,8 @@ class AzureCloudSnapshotInterface(CloudSnapshotInterface):
             resources accessed through this interface belong.
         :param str resource_group|None: The resource_group to which the resources
             accessed through this interface belong.
-        :param azure.identity.AzureCliCredential|azure.identity.ManagedIdentityCredential
+        :param azure.identity.AzureCliCredential|azure.identity.ManagedIdentityCredential|
+            azure.identity.DefaultAzureCredential
             The Azure credential to be used when authenticating against the Azure API.
             If omitted then a DefaultAzureCredential will be created and used.
         """
