@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# © Copyright EnterpriseDB UK Limited 2011-2023
+# © Copyright EnterpriseDB UK Limited 2011-2025
 #
 # This file is part of Barman.
 #
@@ -60,7 +60,7 @@ from barman.exceptions import (
     SnapshotBackupException,
 )
 from barman.infofile import BackupInfo, LocalBackupInfo, SyntheticBackupInfo
-from barman.utils import force_str, mkpath, total_seconds
+from barman.utils import force_str, mkpath, parse_target_tli, total_seconds
 
 # generic logger for this module
 _logger = logging.getLogger(__name__)
@@ -95,6 +95,7 @@ class RecoveryExecutor(object):
         self,
         backup_info,
         dest,
+        wal_dest=None,
         tablespaces=None,
         remote_command=None,
         target_tli=None,
@@ -115,6 +116,9 @@ class RecoveryExecutor(object):
 
         :param barman.infofile.BackupInfo backup_info: the backup to recover
         :param str dest: the destination directory
+        :param str|None wal_dest: the destination directory for WALs when doing PITR.
+            See :meth:`~barman.recovery_executor.RecoveryExecutor._set_pitr_targets`
+            for more details.
         :param dict[str,str]|None tablespaces: a tablespace
             name -> location map (for relocation)
         :param str|None remote_command: The remote command to recover
@@ -164,6 +168,7 @@ class RecoveryExecutor(object):
             recovery_info,
             backup_info,
             dest,
+            wal_dest,
             target_name,
             target_time,
             target_tli,
@@ -246,6 +251,20 @@ class RecoveryExecutor(object):
                         "option for recovery"
                     )
 
+            # check WALs destination directory. If doesn't exist create it
+            # we use the value from recovery_info as it contains the final path
+            try:
+                recovery_info["cmd"].create_dir_if_not_exists(
+                    recovery_info["wal_dest"], mode="700"
+                )
+            except FsOperationFailed as e:
+                output.error(
+                    "unable to initialise WAL destination directory '%s': %s",
+                    wal_dest,
+                    e,
+                )
+                output.close_and_exit()
+
             output.info("Copying required WAL segments.")
 
             required_xlog_files = ()  # Makes static analysers happy
@@ -374,7 +393,6 @@ class RecoveryExecutor(object):
         results = {
             "changes": [],
             "warnings": [],
-            "delete_barman_wal": False,
             "missing_files": [],
             "get_wal": False,
             "recovery_start_time": datetime.datetime.now(dateutil.tz.tzlocal()),
@@ -428,6 +446,7 @@ class RecoveryExecutor(object):
         recovery_info,
         backup_info,
         dest,
+        wal_dest,
         target_name,
         target_time,
         target_tli,
@@ -444,6 +463,7 @@ class RecoveryExecutor(object):
         :param barman.infofile.LocalBackupInfo backup_info: representation of a
             backup
         :param str dest: destination directory of the recovery
+        :param str|None wal_dest: the destination directory for WALs when doing PITR
         :param str|None target_name: recovery target name for PITR
         :param str|None target_time: recovery target time for PITR
         :param str|None target_tli: recovery target timeline for PITR
@@ -456,22 +476,15 @@ class RecoveryExecutor(object):
         target_datetime = None
 
         # Calculate the integer value of TLI if a keyword is provided
-        calculated_target_tli = target_tli
-        if target_tli and type(target_tli) is str:
-            if target_tli == "current":
-                calculated_target_tli = backup_info.timeline
-            elif target_tli == "latest":
-                valid_timelines = self.backup_manager.get_latest_archived_wals_info()
-                calculated_target_tli = int(max(valid_timelines.keys()), 16)
-            elif not target_tli.isdigit():
-                raise ValueError("%s is not a valid timeline keyword" % target_tli)
+        calculated_target_tli = parse_target_tli(
+            self.backup_manager, target_tli, backup_info
+        )
 
         d_immediate = backup_info.version >= 90400 and target_immediate
         d_lsn = backup_info.version >= 100000 and target_lsn
-        d_tli = calculated_target_tli != backup_info.timeline and calculated_target_tli
 
         # Detect PITR
-        if target_time or target_xid or d_tli or target_name or d_immediate or d_lsn:
+        if any([target_time, target_xid, target_tli, target_name, d_immediate, d_lsn]):
             recovery_info["is_pitr"] = True
             targets = {}
             if target_time:
@@ -516,8 +529,8 @@ class RecoveryExecutor(object):
                 targets["xid"] = str(target_xid)
             if d_lsn:
                 targets["lsn"] = str(d_lsn)
-            if d_tli:
-                targets["timeline"] = str(d_tli)
+            if target_tli:
+                targets["timeline"] = str(calculated_target_tli)
             if target_name:
                 targets["name"] = str(target_name)
             if d_immediate:
@@ -551,13 +564,12 @@ class RecoveryExecutor(object):
                 "Doing PITR. Recovery target %s",
                 (", ".join(["%s: %r" % (k, v) for k, v in targets.items()])),
             )
-            recovery_info["wal_dest"] = os.path.join(dest, "barman_wal")
-
-            # With a PostgreSQL version older than 8.4, it is the user's
-            # responsibility to delete the "barman_wal" directory as the
-            # restore_command option in recovery.conf is not supported
-            if backup_info.version < 80400 and not recovery_info["get_wal"]:
-                recovery_info["results"]["delete_barman_wal"] = True
+            # If a custom WALs directory has been given, use it, otherwise defaults to
+            # using a `barman_wal` directory inside the destination directory
+            if wal_dest:
+                recovery_info["wal_dest"] = wal_dest
+            else:
+                recovery_info["wal_dest"] = os.path.join(dest, "barman_wal")
         else:
             # Raise an error if target_lsn is used with a pgversion < 10
             if backup_info.version < 100000:
@@ -1008,10 +1020,11 @@ class RecoveryExecutor(object):
         :param bool|None standby_mode: standby mode
         """
 
+        wal_dest = recovery_info["wal_dest"]
         recovery_conf_lines = []
         # If GET_WAL has been set, use the get-wal command to retrieve the
         # required wal files. Otherwise use the unix command "cp" to copy
-        # them from the barman_wal directory
+        # them from the wal_dest directory
         if recovery_info["get_wal"]:
             partial_option = ""
             if not standby_mode:
@@ -1048,10 +1061,15 @@ class RecoveryExecutor(object):
                     % (self.config.config.user, partial_option, self.config.name)
                 )
             recovery_info["results"]["get_wal"] = True
-        else:
-            recovery_conf_lines.append("restore_command = 'cp barman_wal/%f %p'")
-        if backup_info.version >= 80400 and not recovery_info["get_wal"]:
-            recovery_conf_lines.append("recovery_end_command = 'rm -fr barman_wal'")
+        elif not standby_mode:
+            # We copy all the needed WAL files to the wal_dest directory when get-wal
+            # is not requested, except when we are in standby mode. In the case of
+            # standby mode, the server will not exit recovery, so the
+            # recovery_end_command would never be executed.
+            # For this reason, with standby_mode, we need to copy the WAL files
+            # directly in the pg_wal directory.
+            recovery_conf_lines.append(f"restore_command = 'cp {wal_dest}/%f %p'")
+            recovery_conf_lines.append(f"recovery_end_command = 'rm -fr {wal_dest}'")
 
         # Writes recovery target
         if target_time:
@@ -1686,6 +1704,7 @@ class SnapshotRecoveryExecutor(RemoteConfigRecoveryExecutor):
         self,
         backup_info,
         dest,
+        wal_dest=None,
         tablespaces=None,
         remote_command=None,
         target_tli=None,
@@ -1707,6 +1726,9 @@ class SnapshotRecoveryExecutor(RemoteConfigRecoveryExecutor):
 
         :param barman.infofile.BackupInfo backup_info: the backup to recover
         :param str dest: the destination directory
+        :param str|None wal_dest: the destination directory for WALs when doing PITR.
+            See :meth:`~barman.recovery_executor.RecoveryExecutor._set_pitr_targets`
+            for more details.
         :param dict[str,str]|None tablespaces: a tablespace
             name -> location map (for relocation)
         :param str|None remote_command: The remote command to recover
@@ -1740,6 +1762,7 @@ class SnapshotRecoveryExecutor(RemoteConfigRecoveryExecutor):
         return super(SnapshotRecoveryExecutor, self).recover(
             backup_info,
             dest,
+            wal_dest=wal_dest,
             tablespaces=None,
             remote_command=remote_command,
             target_tli=target_tli,
@@ -1830,7 +1853,7 @@ class IncrementalRecoveryExecutor(RemoteConfigRecoveryExecutor):
         self.combine_start_time = None
         self.combine_end_time = None
 
-    def recover(self, backup_info, dest, remote_command=None, **kwargs):
+    def recover(self, backup_info, dest, wal_dest=None, remote_command=None, **kwargs):
         """
         Performs the recovery of an incremental backup.
 
@@ -1842,6 +1865,9 @@ class IncrementalRecoveryExecutor(RemoteConfigRecoveryExecutor):
         :param barman.infofile.BackupInfo backup_info: the incremental
             backup to recover
         :param str dest: the destination directory
+        :param str|None wal_dest: the destination directory for WALs when doing PITR.
+            See :meth:`~barman.recovery_executor.RecoveryExecutor._set_pitr_targets`
+            for more details.
         :param str|None remote_command: The remote command to recover
             the base backup, in case of remote backup.
         :return dict: ``recovery_info`` dictionary, holding the values related
@@ -1857,7 +1883,11 @@ class IncrementalRecoveryExecutor(RemoteConfigRecoveryExecutor):
 
         # Perform the standard recovery process passing the synthetic backup
         recovery_info = super(IncrementalRecoveryExecutor, self).recover(
-            synthetic_backup_info, dest, remote_command=remote_command, **kwargs
+            synthetic_backup_info,
+            dest,
+            wal_dest,
+            remote_command=remote_command,
+            **kwargs,
         )
 
         # If the checksum configuration is not consistent among all backups in the chain, we
@@ -1999,9 +2029,21 @@ class IncrementalRecoveryExecutor(RemoteConfigRecoveryExecutor):
         # Then procede to move the content of the data directory
         # We don't move the pg_tblspc as the _prepare_tablespaces method called earlier
         # in the process already created this directory and required symlinks in the destination
+        # We also ignore any of the log directories and files not useful for the recovery
         data_source = backup_info.get_data_directory()
         self._move_to_destination(
-            source=data_source, destination=dest, exclude_path_names={"pg_tblspc"}
+            source=data_source,
+            destination=dest,
+            exclude_path_names={
+                "pg_tblspc",
+                "pg_log",
+                "log",
+                "pg_xlog",
+                "pg_wal",
+                "postmaster.pid",
+                "recovery.conf",
+                "tablespace_map",
+            },
         )
 
     def _move_to_destination(self, source, destination, exclude_path_names=set()):
