@@ -37,7 +37,7 @@ from testing_helpers import (
 )
 
 import barman.utils
-from barman.infofile import WalFileInfo, load_datetime_tz
+from barman.infofile import BackupInfo, WalFileInfo, load_datetime_tz
 from barman.lockfile import LockFile
 
 LOGFILE_NAME = "logfile.log"
@@ -1026,6 +1026,75 @@ class TestCheckBackupNames(object):
         # THEN None is returned
         assert backup_info is None
 
+    @pytest.mark.parametrize(
+        "shortcut",
+        (
+            "latest",
+            "last",
+            "oldest",
+            "first",
+            "last-failed",
+            "latest-full",
+            "last-full",
+            "12345",
+        ),
+    )
+    @mock.patch("barman.utils.is_backup_id")
+    def test_get_backup_id_using_shortcut(
+        self,
+        mock_is_backup_id,
+        shortcut,
+    ):
+        backup_manager = build_backup_manager()
+        server = backup_manager.server
+        barman.utils.get_backup_id_using_shortcut(server, shortcut, BackupInfo)
+        if shortcut in ("latest", "last"):
+            server.get_last_backup_id.assert_called_once_with()
+        elif shortcut in ("oldest", "first"):
+            server.get_first_backup_id.assert_called_once_with()
+        elif shortcut in ("last-failed"):
+            server.get_last_backup_id.assert_called_once_with([BackupInfo.FAILED])
+        elif shortcut in ("latest-full", "last-full"):
+            server.get_last_full_backup_id.assert_called_once_with()
+        else:
+            mock_is_backup_id.assert_called_once_with(shortcut)
+
+    def test_get_backup_info_from_name(self):
+        """
+        Test the `get_backup_info_from_name` from utils will return the correct
+        backup based on a named backup.
+        """
+        backup_manager = build_backup_manager()
+
+        available_backups = {
+            "20250108T120000": {
+                "status": "DONE",
+            },
+            "20250107T120000": {
+                "status": "DONE",
+            },
+            "20250106T120000": {
+                "status": "DONE",
+                "backup_name": "my_test_backup",
+            },
+        }
+
+        backups = dict(
+            (
+                bkp_id,
+                build_test_backup_info(
+                    server=backup_manager.server, backup_id=bkp_id, **bkp_metadata
+                ),
+            )
+            for bkp_id, bkp_metadata in available_backups.items()
+        )
+
+        backup_info = barman.utils.get_backup_info_from_name(
+            backups.values(), "my_test_backup"
+        )
+
+        assert backup_info == backups["20250106T120000"]
+
 
 class TestBackupRecoveryTargets(object):
     @pytest.mark.parametrize(
@@ -1077,6 +1146,25 @@ class TestBackupRecoveryTargets(object):
 
         assert backup_id == expected_backup_id
 
+    def test_get_backup_id_from_target_time_raise_error(self):
+        """
+        Test the get_backup_id_from_target_time from utils will raise the correct error
+        and output the correct error.
+        """
+        available_backups = mock.Mock()
+
+        target_time = "2025-10-1020:00:00"
+
+        error_msg = (
+            "Unable to parse the target time parameter '2025-10-1020:00:00': "
+            "Unknown string format: 2025-10-1020:00:00"
+        )
+
+        with pytest.raises(ValueError, match=error_msg):
+            _ = barman.utils.get_backup_id_from_target_time(
+                available_backups.values(), target_time
+            )
+
     @pytest.mark.parametrize(
         ("target_lsn", "expected_backup_id"),
         [
