@@ -131,6 +131,7 @@ def build_test_backup_info(
         server.config = build_config_from_dicts().get_server("main")
         server.passive_node = False
         server.backup_manager.name = "default"
+        server.meta_directory = "%s/meta" % server.config.backup_directory
 
     backup_info = LocalBackupInfo(**locals())
     return backup_info
@@ -280,6 +281,7 @@ def build_config_dictionary(config_keys=None):
         "active": True,
         "active_model": None,
         "archiver": True,
+        "worm_mode": False,
         "archiver_batch_size": 0,
         "autogenerate_manifest": False,
         "aws_await_snapshots_timeout": 3600,
@@ -465,6 +467,7 @@ def build_mocked_server(
     server.path = "/test/bin"
     server.systemid = "6721602258895701769"
     server.postgres.server_version = pg_version
+    server.meta_directory = "%s/meta" % server.config.backup_directory
     return server
 
 
